@@ -2,7 +2,7 @@
 #' @rdname createDataPartition
 #' @export
 createResample <- function(y, times = 10, list = TRUE) {
-  if (class(y)[1] == "Surv")
+  if (inherits(y, "Surv"))
     y <- y[, "time"]
   trainIndex <- matrix(0, ncol = times, nrow = length(y))
   out <- apply(
