@@ -172,7 +172,7 @@ rfe <- function (x, ...) UseMethod("rfe")
   function(x, y,
            sizes = 2^(2:4),
            metric = ifelse(is.factor(y), "Accuracy", "RMSE"),
-           maximize = ifelse(metric == "RMSE", FALSE, TRUE),
+           maximize = ifelse(metric %in% c("RMSE", "MAE", "logLoss"), FALSE, TRUE),
            rfeControl = rfeControl(), ...)
   {
     startTime <- proc.time()
@@ -502,6 +502,9 @@ rfeIter <- function(x, y,
                  "There may be linear dependencies in your predictor variables"),
               call. = FALSE)
     }
+    if (!any(names(modImp) == "var")) {
+      stop("The importance score data should include a column named `var`.")
+    }
     finalVariables[[k]] <- subset(modImp, var %in% retained)
     finalVariables[[k]]$Variables <- sizeValues[[k]]
     if(k < length(sizeValues)) retained <- as.character(modImp$var)[1:sizeValues[k+1]]
@@ -547,7 +550,7 @@ rfeIter <- function(x, y,
 #' @seealso \code{\link{rfe}}, \code{\link[lattice]{xyplot}},
 #' \code{\link[ggplot2]{ggplot}}
 #' @references Kuhn (2008), ``Building Predictive Models in R Using the caret''
-#' (\url{http://www.jstatsoft.org/article/view/v028i05/v28i05.pdf})
+#' (\doi{10.18637/jss.v028.i05})
 #' @keywords hplot
 #' @method plot rfe
 #' @export
@@ -569,7 +572,6 @@ rfeIter <- function(x, y,
 #' plot(lmProfile, metric = "Rsquared")
 #' ggplot(lmProfile)
 #' }
-#' @method plot rfe
 #' @export plot.rfe
 plot.rfe <- function (x,
                       metric = x$metric,
@@ -1616,7 +1618,7 @@ rfe_rec <- function(x, y, test_x, test_y, perf_dat,
       metric <- ifelse(is.factor(y_dat), "Accuracy", "RMSE")
 
     maximize <-
-      ifelse(metric %in% c("RMSE", "MAE"), FALSE, TRUE) # TODO make a function
+      ifelse(metric %in% c("RMSE", "MAE", "logLoss"), FALSE, TRUE) # TODO make a function
 
 
 
