@@ -361,8 +361,7 @@ safsControl <- function(functions = NULL,
        allowParallel = allowParallel)
 }
 
-#' @title Simulated annealing feature selection
-#'
+#' Simulated annealing feature selection
 #'
 #' @description
 #' Supervised feature selection using simulated annealing
@@ -371,6 +370,8 @@ safsControl <- function(functions = NULL,
 #' space using simulated annealing (SA). See Kirkpatrick et al (1983) for more
 #' information on this search algorithm.
 #'
+#' @details
+#'
 #' This function conducts the search of the feature space repeatedly within
 #' resampling iterations. First, the training data are split be whatever
 #' resampling method was specified in the control function. For example, if
@@ -451,7 +452,7 @@ safsControl <- function(functions = NULL,
 #' @param data an object of class \code{\link{rfe}}.
 #' @param iters number of search iterations
 #' @param differences a logical: should the difference in fitness values with
-#' and without each predictor be calculated
+#' and without each predictor be calculated?
 #' @param safsControl a list of values that define how this function acts. See
 #' \code{\link{safsControl}} and URL.
 #' @param \dots arguments passed to the classification or regression routine
@@ -506,7 +507,7 @@ safs <- function (x, ...) UseMethod("safs")
     if(is.null(safsControl$metric))
       safsControl$metric <- rep(ifelse(is.factor(y), "Accuracy", "RMSE"), 2)
     if(is.null(safsControl$maximize))
-      safsControl$maximize <- rep(ifelse(safsControl$metric == "RMSE", FALSE, TRUE), 2)
+      safsControl$maximize <- rep(ifelse(safsControl$metric %in% c("RMSE", "MAE", "logLoss"), FALSE, TRUE), 2)
     if(is.null(names(safsControl$metric)))
       names(safsControl$metric) <- c("internal", "external")
     if(is.null(names(safsControl$maximize)))
@@ -601,8 +602,12 @@ safs <- function (x, ...) UseMethod("safs")
                                  colnames(x)),
                    silent = TRUE)
       if (inherits(diffs, "try-error")) {
+
+        msg <- strsplit(as.character(diffs), " :", fixed = TRUE)[[1]][2]
+        warning(
+          paste0("Variable differences could not be computed:", msg)
+        )
         diffs <- NULL
-        warning("An error occured when computing the variable differences")
       }
     } else diffs <- NULL
     rm(result)
@@ -1348,7 +1353,7 @@ update.safs <- function(object, iter, x, y, ...) {
     if(is.null(safsControl$metric))
       safsControl$metric <- rep(ifelse(is.factor(y), "Accuracy", "RMSE"), 2)
     if(is.null(safsControl$maximize))
-      safsControl$maximize <- rep(ifelse(safsControl$metric == "RMSE", FALSE, TRUE), 2)
+      safsControl$maximize <- rep(ifelse(safsControl$metric %in% c("RMSE", "MAE", "logLoss"), FALSE, TRUE), 2)
     if(is.null(names(safsControl$metric)))
       names(safsControl$metric) <- c("internal", "external")
     if(is.null(names(safsControl$maximize)))
