@@ -154,7 +154,7 @@
 #' @references \url{http://topepo.github.io/caret/}
 #'
 #' Kuhn (2008), ``Building Predictive Models in R Using the caret''
-#' (\url{http://www.jstatsoft.org/article/view/v028i05/v28i05.pdf})
+#' (\doi{10.18637/jss.v028.i05})
 #'
 #' \url{https://topepo.github.io/recipes/}
 #' @keywords models
@@ -302,12 +302,18 @@ train.default <- function(x, y,
                           ...,
                           weights = NULL,
                           metric = ifelse(is.factor(y), "Accuracy", "RMSE"),
-                          maximize = ifelse(metric %in% c("RMSE", "logLoss", "MAE"), FALSE, TRUE),
+                          maximize = ifelse(metric %in% c("RMSE", "logLoss", "MAE", "logLoss"), FALSE, TRUE),
                           trControl = trainControl(),
                           tuneGrid = NULL,
                           tuneLength = ifelse(trControl$method == "none", 1, 3)) {
   startTime <- proc.time()
 
+  if (is.vector(x)) {
+    ptype <- NULL
+  } else {
+    ptype <- x[0,,drop = FALSE]
+  }
+
   ## get a seed before packages are loaded or recipes are processed
   rs_seed <- sample.int(.Machine$integer.max, 1L)
 
@@ -317,7 +323,7 @@ train.default <- function(x, y,
   if(is.character(y)) y <- as.factor(y)
 
   if( !is.numeric(y) & !is.factor(y) ){
-    msg <- paste("Please make sure that the outcome column is a factor or numeric .",
+    msg <- paste("Please make sure that the outcome column is a factor or numeric.",
                  "The class(es) of the column:",
                  paste0("'", class(y), "'", collapse = ", "))
 
@@ -374,9 +380,9 @@ train.default <- function(x, y,
     trControl$sampling <- parse_sampling(trControl$sampling)
   }
 
-  if(any(class(x) == "data.table")) x <- as.data.frame(x, stringsAsFactors = TRUE)
+  if(inherits(x, "data.table")) x <- as.data.frame(x, stringsAsFactors = TRUE)
   check_dims(x = x, y = y)
-  n <- if(class(y)[1] == "Surv") nrow(y) else length(y)
+  n <- if(inherits(y, "Surv")) nrow(y) else length(y)
 
   ## TODO add check method and execute here
 
@@ -459,7 +465,7 @@ train.default <- function(x, y,
   ## and data for some models (rpart, pam, etc - see manual for more details)
   if(is.null(tuneGrid)) {
     if(!is.null(ppOpt) && length(models$parameters$parameter) > 1 &&
-         as.character(models$parameters$parameter) != "parameter") {
+         all(as.character(models$parameters$parameter) != "parameter")) {
       pp <- list(method = ppOpt$options)
       if("ica" %in% pp$method) pp$n.comp <- ppOpt$ICAcomp
       if("pca" %in% pp$method) pp$thresh <- ppOpt$thresh
@@ -828,18 +834,19 @@ train.default <- function(x, y,
   indexFinal <- if(is.null(trControl$indexFinal)) seq(along = y) else trControl$indexFinal
 
   if(!(length(trControl$seeds) == 1 && is.na(trControl$seeds))) set.seed(trControl$seeds[[length(trControl$seeds)]][1])
-  finalTime <- system.time(
-    finalModel <- createModel(x = subset_x(x, indexFinal),
-                              y = y[indexFinal],
-                              wts = weights[indexFinal],
-                              method = models,
-                              tuneValue = bestTune,
-                              obsLevels = classLevels,
-                              pp = ppOpt,
-                              last = TRUE,
-                              classProbs = trControl$classProbs,
-                              sampling = trControl$sampling,
-                              ...))
+  startFinalTime <- proc.time()
+  finalModel <- createModel(x = subset_x(x, indexFinal),
+                            y = y[indexFinal],
+                            wts = weights[indexFinal],
+                            method = models,
+                            tuneValue = bestTune,
+                            obsLevels = classLevels,
+                            pp = ppOpt,
+                            last = TRUE,
+                            classProbs = trControl$classProbs,
+                            sampling = trControl$sampling,
+                            ...)
+  endFinalTime <- proc.time()
 
   if(trControl$trim && !is.null(models$trim)) {
     if(trControl$verboseIter) old_size <- object.size(finalModel$fit)
@@ -867,7 +874,10 @@ train.default <- function(x, y,
   if(method == "glmnet") finalModel$lambdaOpt <- bestTune$lambda
 
   if(trControl$returnData) {
-    outData <- if(!is.data.frame(x)) try(as.data.frame(x, stringsAsFactors = TRUE), silent = TRUE) else x
+    outData <- if (inherits(x, "sparseMatrix")) as.matrix(x) else x
+    if(!is.data.frame(outData)) {
+      outData <- try(as.data.frame(outData, stringsAsFactors = TRUE), silent = TRUE)
+    }
     if(inherits(outData, "try-error")) {
       warning("The training data could not be converted to a data frame for saving")
       outData <- NULL
@@ -882,7 +892,7 @@ train.default <- function(x, y,
 
   endTime <- proc.time()
   times <- list(everything = endTime - startTime,
-                final = finalTime)
+                final = endFinalTime - startFinalTime)
 
   out <- structure(list(method = method,
                         modelInfo = models,
@@ -897,6 +907,7 @@ train.default <- function(x, y,
                         finalModel = finalModel,
                         preProcess = pp,
                         trainingData = outData,
+                        ptype = ptype,
                         resample = byResample,
                         resampledCM = resampledCM,
                         perfNames = perfNames,
@@ -936,6 +947,7 @@ train.formula <- function (form, data, ..., weights, subset, na.action = na.fail
   m <- eval.parent(m)
   if(nrow(m) < 1) stop("Every row has at least one missing value were found", call. = FALSE)
   Terms <- attr(m, "terms")
+  ptype <- terms_ptype(Terms, data)
   x <- model.matrix(Terms, m, contrasts)
   cons <- attr(x, "contrast")
   int_flag <- grepl("(Intercept)", colnames(x))
@@ -950,6 +962,7 @@ train.formula <- function (form, data, ..., weights, subset, na.action = na.fail
   res$na.action <- attr(m, "na.action")
   res$contrasts <- cons
   res$xlevels <- .getXlevels(Terms, m)
+  res$ptype <- ptype
   if(!is.null(res$trainingData)) {
     ## We re-save the original data from the formula interface
     ## since it has not been converted to dummy variables.
@@ -1074,7 +1087,7 @@ train.recipe <- function(x,
   }
 
   check_dims(x = x_dat, y = y_dat)
-  n <- if(class(y_dat)[1] == "Surv") nrow(y_dat) else length(y_dat)
+  n <- if(inherits(y_dat, "Surv")) nrow(y_dat) else length(y_dat)
 
   ## Some models that use RWeka start multiple threads and this conflicts with multicore:
   parallel_check("RWeka", models)
